@@ -7,6 +7,7 @@
 #include <functions/Equal.h>
 #include <functions/GreaterOrEqual.h>
 #include <functions/GreaterThan.h>
+#include <functions/IfElse.h>
 #include <functions/LessOrEqual.h>
 #include <functions/LessThan.h>
 #include <functions/Multiply.h>
@@ -45,6 +46,7 @@ namespace base {
 	insert(new Equal);
 	insert(new GreaterOrEqual);
 	insert(new GreaterThan);
+        insert(new IfElse);
 	insert(new LessOrEqual);
 	insert(new LessThan);
 	insert(new Multiply);
