@@ -8,11 +8,11 @@ using std::floor;
 
 namespace bugs {
 
-    Round::Round ():ScalarFunc ("round", 1)
+    Round::Round ():ScalarFunction ("round", 1)
     {
     }
 
-    double Round::evaluateScalar(vector<double const *> const &args) const
+    double Round::evaluate(vector<double const *> const &args) const
     {
 	/* The C99 round function does not exist in the current C++ standard */
 	return floor(*args[0] + 0.5);
