@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 /**
  * Conjugate sampler for the normal distribution.
  * A conjugate sampler can be created for a stochastic node "snode"
@@ -22,4 +24,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_NORMAL_H_ */
