@@ -11,7 +11,6 @@
 #include <sampler/GraphView.h>
 
 #include <set>
-#include <stdexcept>
 #include <vector>
 #include <cmath>
 
@@ -20,10 +19,10 @@
 using std::vector;
 using std::set;
 using std::sqrt;
-using std::invalid_argument;
-using std::logic_error;
 using std::string;
 
+namespace bugs {
+
 bool ConjugateWishart::canSample(StochasticNode *snode, Graph const &graph)
 {
     if (getDist(snode) != WISH)
@@ -148,3 +147,5 @@ string ConjugateWishart::name() const
 {
     return "ConjugateWishart";
 }
+
+}
