@@ -3,9 +3,6 @@
 #include "samplers/LinearFactory.h"
 #include "samplers/LinearGibbsFactory.h"
 #include "samplers/IWLSFactory.h"
-/*
-#include "samplers/HolmesHeldBFactory.h"
-*/
 #include "samplers/HolmesHeldFactory.h"
 #include "samplers/AlbertChibFactory.h"
 #include "samplers/AlbertChibGibbsFactory.h"
@@ -48,7 +45,6 @@ namespace glm {
  	insert(new AMFactory);
 	insert(new AlbertChibGibbsFactory);
 	insert(new AlbertChibFactory);
-	//insert(new HolmesHeldBFactory);
 	insert(new HolmesHeldFactory);
 	insert(new ConjugateFFactory);
     }
